@@ -1,8 +1,6 @@
-# flake8: noqa
 import collections
 import re
 import sys
-from typing import Tuple
 
 from .base import ClosableResponse, EmptyResponse, Header, Method, Request, Response, UnexpectedContentTypeError
 from .circuit_breaker import (
@@ -14,23 +12,30 @@ from .circuit_breaker import (
     NoopCircuitBreaker,
     RollingCircuitBreakerMetrics,
 )
-from .client import Client, DefaultClient
+from .client import Client
 from .context import get_context, set_context
 from .deadline import Deadline
-from .delays_provider import constant_delays, linear_delays
-from .metrics import NOOP_METRICS_PROVIDER, MetricsProvider, NoopMetricsProvider
-from .pipeline import (
-    BypassModule,
-    LowTimeoutModule,
-    MetricsModule,
-    NextModuleFunc,
-    RequestModule,
-    TracingModule,
-    TransportModule,
-    build_pipeline,
-)
+from .deadline_provider import DeadlineProvider, pass_deadline_through, split_deadline_between_attempts
+from .delays_provider import constant_delays, linear_backoff_delays, linear_delays
+from .deprecated import NOOP_METRICS_PROVIDER, MetricsProvider, NoopMetricsProvider
+from .endpoint_provider import DelegateEndpointProvider, EndpointProvider, StaticEndpointProvider
+from .pipeline import BypassModule, LowTimeoutModule, NextModuleFunc, RequestModule, TransportModule, build_pipeline
 from .priority import Priority
-from .request import delete, get, patch, patch_json, post, post_json, put, put_json
+from .request import (
+    AsyncRequestEnricher,
+    DeprecatedAsyncRequestEnricher,
+    RequestEnricher,
+    delete,
+    get,
+    patch,
+    patch_json,
+    post,
+    post_json,
+    put,
+    put_json,
+    request,
+    request_json,
+)
 from .request_strategy import (
     MethodBasedStrategy,
     ParallelRequestStrategy,
@@ -47,10 +52,9 @@ from .request_strategy import (
 )
 from .response_classifier import DefaultResponseClassifier, ResponseClassifier, ResponseVerdict
 from .setup import setup, setup_v2
-from .tracing import NOOP_TRACER, NoopSpan, NoopTracer, Span, Tracer
 from .transport import Transport
 
-__all__: Tuple[str, ...] = (
+__all__: tuple[str, ...] = (
     # base.py
     "ClosableResponse",
     "EmptyResponse",
@@ -69,26 +73,32 @@ __all__: Tuple[str, ...] = (
     "RollingCircuitBreakerMetrics",
     # client.py
     "Client",
-    "DefaultClient",
     # context.py
     "get_context",
     "set_context",
     # deadline.py
     "Deadline",
+    # deadline_provider.py
+    "DeadlineProvider",
+    "pass_deadline_through",
+    "split_deadline_between_attempts",
     # delays_provider.py
     "constant_delays",
+    "linear_backoff_delays",
     "linear_delays",
-    # metrics.py
-    "NOOP_METRICS_PROVIDER",
+    # deprecated.py
     "MetricsProvider",
+    "NOOP_METRICS_PROVIDER",
     "NoopMetricsProvider",
+    # endpoint_provider.py
+    "EndpointProvider",
+    "DelegateEndpointProvider",
+    "StaticEndpointProvider",
     # pipeline.py
     "BypassModule",
     "LowTimeoutModule",
-    "MetricsModule",
     "NextModuleFunc",
     "RequestModule",
-    "TracingModule",
     "TransportModule",
     "build_pipeline",
     # priority.py
@@ -102,6 +112,11 @@ __all__: Tuple[str, ...] = (
     "post_json",
     "put",
     "put_json",
+    "request",
+    "request_json",
+    "RequestEnricher",
+    "AsyncRequestEnricher",
+    "DeprecatedAsyncRequestEnricher",
     # request_strategy.py
     "MethodBasedStrategy",
     "ParallelRequestStrategy",
@@ -122,46 +137,46 @@ __all__: Tuple[str, ...] = (
     # setup.py
     "setup",
     "setup_v2",
-    # tracing.py
-    "NOOP_TRACER",
-    "NoopSpan",
-    "NoopTracer",
-    "Span",
-    "Tracer",
     # transport.py
     "Transport",
 )
-
 try:
-    import aiohttp
+    import aiohttp  # noqa
 
     from .aiohttp import AioHttpDnsResolver, AioHttpTransport, aiohttp_middleware_factory, aiohttp_timeout
 
-    __all__ += ("AioHttpDnsResolver", "AioHttpTransport", "aiohttp_middleware_factory", "aiohttp_timeout")
+    __all__ += (
+        "AioHttpDnsResolver",
+        "AioHttpTransport",
+        "aiohttp_middleware_factory",
+        "aiohttp_timeout",
+    )  # type: ignore
 except ImportError:
     pass
 
 try:
-    import prometheus_client
+    import httpx  # noqa
 
-    from .prometheus import PROMETHEUS_METRICS_PROVIDER, PrometheusMetricsProvider
+    from .httpx import HttpxTransport
 
-    __all__ += ("PROMETHEUS_METRICS_PROVIDER", "PrometheusMetricsProvider")
+    __all__ += ("HttpxTransport",)  # type: ignore
 except ImportError:
     pass
 
 try:
-    import opentelemetry.propagate
-    import opentelemetry.semconv
-    import opentelemetry.trace
+    import prometheus_client  # noqa
 
-    from .opentelemetry import OpenTelemetryTracer
+    # Deprecated as well as MetricsProvider, NoopMetricsProvider and NOOP_METRICS_PROVIDER.
+    # For backward compatibility.
+    PROMETHEUS_METRICS_PROVIDER = NOOP_METRICS_PROVIDER
+    PrometheusMetricsProvider = NoopMetricsProvider
 
-    __all__ += ("OpenTelemetryTracer",)
+    __all__ += ("PROMETHEUS_METRICS_PROVIDER", "PrometheusMetricsProvider")  # type: ignore
 except ImportError:
     pass
 
-__version__ = "0.1.27"
+
+__version__ = "0.2.1"
 
 version = f"{__version__}, Python {sys.version}"
 
