@@ -1,7 +1,8 @@
 import abc
+import collections.abc
 import json
 import re
-from typing import Any, Callable, Dict, Iterable, List, Mapping, Optional, Tuple, Union
+from typing import Any
 
 import multidict
 import yarl
@@ -9,6 +10,7 @@ import yarl
 from .utils import Closable
 
 EMPTY_HEADERS = multidict.CIMultiDictProxy[str](multidict.CIMultiDict[str]())
+MAX_REDIRECTS = 10
 
 
 class Method:
@@ -21,7 +23,8 @@ class Method:
 
 class Header:
     CONTENT_TYPE = multidict.istr("Content-Type")
-    X_REQUEST_DEADLINE_AT = multidict.istr("X-Request-Deadline-At")
+    CONTENT_LENGTH = multidict.istr("Content-Length")
+    LOCATION = multidict.istr("Location")
     X_REQUEST_PRIORITY = multidict.istr("X-Request-Priority")
     X_REQUEST_TIMEOUT = multidict.istr("X-Request-Timeout")
     X_SERVICE_NAME = multidict.istr("X-Service-Name")
@@ -29,15 +32,14 @@ class Header:
     X_CIRCUIT_BREAKER = multidict.istr("X-Circuit-Breaker")
 
 
-_MultiDict = Union[
-    Mapping[Union[str, multidict.istr], str], multidict.CIMultiDictProxy[str], multidict.CIMultiDict[str]
-]
-
+_MultiDict = (
+    collections.abc.Mapping[str | multidict.istr, str] | multidict.CIMultiDictProxy[str] | multidict.CIMultiDict[str]
+)
 
 json_re = re.compile(r"^application/(?:[\w.+-]+?\+)?json", re.RegexFlag.IGNORECASE)
 
-PathParameters = Mapping[str, Any]
-QueryParameters = Union[Mapping[str, Any], Iterable[Tuple[str, Any]], _MultiDict]
+PathParameters = collections.abc.Mapping[str, Any]
+QueryParameters = collections.abc.Mapping[str, Any] | collections.abc.Iterable[tuple[str, Any]] | _MultiDict
 Headers = _MultiDict
 
 
@@ -59,6 +61,8 @@ class Request:
         "query_parameters",
         "headers",
         "body",
+        "allow_redirects",
+        "max_redirects",
     )
 
     def __init__(
@@ -66,10 +70,12 @@ class Request:
         *,
         method: str,
         url: yarl.URL,
-        path_parameters: Optional[PathParameters] = None,
-        query_parameters: Optional[QueryParameters] = None,
-        headers: Optional[Headers] = None,
-        body: Optional[bytes] = None,
+        path_parameters: PathParameters | None = None,
+        query_parameters: QueryParameters | None = None,
+        headers: Headers | None = None,
+        body: bytes | None = None,
+        allow_redirects: bool = True,
+        max_redirects: int = MAX_REDIRECTS,
     ):
         if url.is_absolute():
             raise RuntimeError("Request url should be relative")
@@ -80,6 +86,8 @@ class Request:
         self.url = url
         self.headers = headers
         self.body = body
+        self.allow_redirects = allow_redirects
+        self.max_redirects = max_redirects
 
     def update_headers(self, headers: Headers) -> "Request":
         updated_headers = (
@@ -93,6 +101,8 @@ class Request:
             query_parameters=self.query_parameters,
             headers=updated_headers,
             body=self.body,
+            allow_redirects=self.allow_redirects,
+            max_redirects=self.max_redirects,
         )
 
     def extend_headers(self, headers: Headers) -> "Request":
@@ -107,6 +117,8 @@ class Request:
             query_parameters=self.query_parameters,
             headers=updated_headers,
             body=self.body,
+            allow_redirects=self.allow_redirects,
+            max_redirects=self.max_redirects,
         )
 
     def __repr__(self) -> str:
@@ -118,31 +130,26 @@ class Response(abc.ABC):
 
     @property
     @abc.abstractmethod
-    def status(self) -> int:
-        ...
+    def status(self) -> int: ...
 
     @property
     @abc.abstractmethod
-    def headers(self) -> multidict.CIMultiDictProxy[str]:
-        ...
+    def headers(self) -> multidict.CIMultiDictProxy[str]: ...
 
     @abc.abstractmethod
     async def json(
         self,
         *,
-        encoding: Optional[str] = None,
-        loads: Callable[[str], Any] = json.loads,
-        content_type: Optional[str] = "application/json",
-    ) -> Any:
-        ...
+        encoding: str | None = None,
+        loads: collections.abc.Callable[[str], Any] = json.loads,
+        content_type: str | None = "application/json",
+    ) -> Any: ...
 
     @abc.abstractmethod
-    async def read(self) -> bytes:
-        ...
+    async def read(self) -> bytes: ...
 
     @abc.abstractmethod
-    async def text(self, encoding: Optional[str] = None) -> str:
-        ...
+    async def text(self, encoding: str | None = None) -> str: ...
 
     def is_informational(self) -> bool:
         return 100 <= self.status < 200
@@ -160,7 +167,7 @@ class Response(abc.ABC):
         return 500 <= self.status < 600
 
     @property
-    def content_type(self) -> Optional[str]:
+    def content_type(self) -> str | None:
         return self.headers.get(Header.CONTENT_TYPE)
 
     @property
@@ -175,34 +182,33 @@ class ClosableResponse(Response, Closable):
     __slots__ = ()
 
     @abc.abstractmethod
-    async def close(self) -> None:
-        ...
+    async def close(self) -> None: ...
 
 
 class EmptyResponse(ClosableResponse):
-    __slots__ = ("_status", "_headers")
+    __slots__ = ("__status", "__headers")
 
     def __init__(self, *, status: int, headers: multidict.CIMultiDictProxy[str] = EMPTY_HEADERS):
-        self._status = status
-        self._headers = headers
+        self.__status = status
+        self.__headers = headers
 
     @property
     def status(self) -> int:
-        return self._status
+        return self.__status
 
     @property
     def headers(self) -> multidict.CIMultiDictProxy[str]:
-        return self._headers
+        return self.__headers
 
     async def json(
         self,
         *,
-        encoding: Optional[str] = None,
-        loads: Optional[Callable[[str], Any]] = json.loads,
-        content_type: Optional[str] = "application/json",
+        encoding: str | None = None,
+        loads: collections.abc.Callable[[str], Any] = json.loads,
+        content_type: str | None = "application/json",
     ) -> Any:
         if content_type is not None:
-            response_content_type = self._headers.get(Header.CONTENT_TYPE, "").lower()
+            response_content_type = self.__headers.get(Header.CONTENT_TYPE, "").lower()
             if not is_expected_content_type(response_content_type, content_type):
                 raise UnexpectedContentTypeError(f"Expected {content_type}, actual {response_content_type}")
 
@@ -211,19 +217,21 @@ class EmptyResponse(ClosableResponse):
     async def read(self) -> bytes:
         return bytes()
 
-    async def text(self, encoding: Optional[str] = None) -> str:
+    async def text(self, encoding: str | None = None) -> str:
         return ""
 
     async def close(self) -> None:
         pass
 
 
-def build_query_parameters(query_parameters: QueryParameters) -> Dict[str, Union[str, List[str]]]:
-    parameters: Dict[str, Union[str, List[str]]] = {}
-    for name, value in query_parameters.items() if isinstance(query_parameters, Mapping) else query_parameters:
+def build_query_parameters(query_parameters: QueryParameters) -> dict[str, str | list[str]]:
+    parameters: dict[str, str | list[str]] = {}
+    for name, value in (
+        query_parameters.items() if isinstance(query_parameters, collections.abc.Mapping) else query_parameters
+    ):
         if value is None:
             continue
-        if not isinstance(value, str) and isinstance(value, Iterable):
+        if not isinstance(value, str) and isinstance(value, collections.abc.Iterable):
             values = [str(v) for v in value if v is not None]
             if not values:
                 continue
@@ -235,7 +243,7 @@ def build_query_parameters(query_parameters: QueryParameters) -> Dict[str, Union
                 else:
                     parameters[name] = [*existing_value, *values]
             else:
-                parameters[name] = values
+                parameters[name] = values  # type: ignore
         else:
             if name in parameters:
                 existing_value = parameters[name]
@@ -244,11 +252,11 @@ def build_query_parameters(query_parameters: QueryParameters) -> Dict[str, Union
                 else:
                     parameters[name] = [*existing_value, str(value)]
             else:
-                parameters[name] = str(value)
+                parameters[name] = str(value)  # type: ignore
     return parameters
 
 
-def substitute_path_parameters(url: yarl.URL, parameters: Optional[PathParameters] = None) -> yarl.URL:
+def substitute_path_parameters(url: yarl.URL, parameters: PathParameters | None = None) -> yarl.URL:
     if not parameters:
         return url
 
@@ -256,7 +264,7 @@ def substitute_path_parameters(url: yarl.URL, parameters: Optional[PathParameter
     for name, value in parameters.items():
         path = path.replace(f"%7B{name}%7D", str(value))
 
-    build_parameters: Dict[str, Any] = dict(
+    build_parameters: dict[str, Any] = dict(
         scheme=url.scheme,
         user=url.raw_user,
         password=url.raw_password,
